Module ad

Module ad 

Automatic differentiation with respect to model parameters.

Structs

BinaryDataset
Binary-mixture dataset: shared data storage plus a property tag.
BoilingTemperature
Boiling temperature of a pure component as function of pressure.
BubblePointPressure
Bubble point pressure of a binary mixture as function of temperature and molefracs of the first component.
BubblePointRecord
The pressure column doubles as the initial guess passed to the VLE solver.
DewPointPressure
Dew point pressure of a binary mixture as function of temperature and molefracs of the first component.
DewPointRecord
The pressure column doubles as the initial guess passed to the VLE solver.
EnthalpyOfVaporization
Enthalpy of vaporization of a pure component as function of temperature.
EnthalpyOfVaporizationRecord
EquilibriumLiquidDensity
Equilibrium liquid density of a pure component as function of temperature.
EquilibriumLiquidDensityRecord
LiquidDensity
Liquid density of a pure component as function of temperature and pressure.
LiquidDensityRecord
PureDataset
Pure-component dataset: shared data storage plus a property tag.
ResidualIsobaricHeatCapacity
Liquid residual isobaric heat capacity of a pure component as function of temperature and pressure.
ResidualIsobaricHeatCapacityRecord
VaporPressure
Vapor pressure of a pure component as function of temperature.
VaporPressureRecord

Enums

BinaryProperty
Binary-mixture properties.
PureProperty
Pure-component properties.

Constants

GRADIENT_SLOTS
Compile-time gradient slot supported by DatasetAD::evaluate_ad.

Traits

Dataset
Dataset that can be evaluated by an equation of state.
DatasetAD
Dataset that supports parameter-gradient evaluation for equations of state implementing ParametersAD<N>.
DatasetRecord
A record that can be collected into a dataset.
ParametersAD
A model that can be evaluated with derivatives of its parameters.
PropertyAD
Properties that can be rapidly evaluated in parallel together with their gradients with respect to model parameters