pub struct BoilingTemperature(pub Pressure);Expand description
Boiling temperature of a pure component as function of pressure.
Tuple Fields
0: PressureTrait Implementations
Sourceimpl<'a> From<&'a [f64]> for BoilingTemperature
impl<'a> From<&'a [f64]> for BoilingTemperature
Sourceimpl<N: Gradients> PropertyAD<N> for BoilingTemperature
impl<N: Gradients> PropertyAD<N> for BoilingTemperature
const REFERENCE: Temperature = KELVIN
type Unit = SIUnit<0, 0, 0, 0, 1, 0, 0>
Sourcefn evaluate<E: Residual<N, D>, D: DualNum<f64, Inner = f64> + Copy>(
&self,
eos: &E,
) -> FeosResult<Temperature<D>>
fn evaluate<E: Residual<N, D>, D: DualNum<f64, Inner = f64> + Copy>( &self, eos: &E, ) -> FeosResult<Temperature<D>>
Evaluate the property for an arbitrary derivative.
Sourcefn evaluate_gradient<E: Residual<N, DualSVec<f64, f64, P>>, const P: usize>(
&self,
eos: &E,
) -> FeosResult<Quantity<DualSVec<f64, f64, P>, Self::Unit>>
fn evaluate_gradient<E: Residual<N, DualSVec<f64, f64, P>>, const P: usize>( &self, eos: &E, ) -> FeosResult<Quantity<DualSVec<f64, f64, P>, Self::Unit>>
Evaluate the property for the first derivative w.r.t. model parameters. Read more
Sourcefn evaluate_parallel<E: Residual<N> + Sync>(
eos: &E,
input: ArrayView2<'_, f64>,
) -> (Array1<f64>, Array1<bool>)
fn evaluate_parallel<E: Residual<N> + Sync>( eos: &E, input: ArrayView2<'_, f64>, ) -> (Array1<f64>, Array1<bool>)
Evaluate the property for all inputs in parallel. Read more
Sourcefn evaluate_parallel_derivatives<E: ParametersAD<N>, const P: usize>(
parameter_names: [String; P],
parameters: &[f64],
input: ArrayView2<'_, f64>,
) -> (Array1<f64>, Array2<f64>, Array1<bool>)
fn evaluate_parallel_derivatives<E: ParametersAD<N>, const P: usize>( parameter_names: [String; P], parameters: &[f64], input: ArrayView2<'_, f64>, ) -> (Array1<f64>, Array2<f64>, Array1<bool>)
Evaluate the property and its gradients for all inputs in parallel. Read more
Sourcefn evaluate_parallel_derivatives_params<E: ParametersAD<N>, const P: usize>(
parameter_names: [String; P],
parameters: ArrayView2<'_, f64>,
input: ArrayView2<'_, f64>,
) -> (Array1<f64>, Array2<f64>, Array1<bool>)
fn evaluate_parallel_derivatives_params<E: ParametersAD<N>, const P: usize>( parameter_names: [String; P], parameters: ArrayView2<'_, f64>, input: ArrayView2<'_, f64>, ) -> (Array1<f64>, Array2<f64>, Array1<bool>)
Evaluate the property and its gradients for all inputs and parameters in parallel. Read more