pub struct EquilibriumLiquidDensity(pub Temperature);Expand description
Equilibrium liquid density of a pure component as function of temperature.
Tuple Fields
0: TemperatureTrait Implementations
Sourceimpl<'a> From<&'a [f64]> for EquilibriumLiquidDensity
impl<'a> From<&'a [f64]> for EquilibriumLiquidDensity
Sourceimpl<N: Gradients> PropertyAD<N> for EquilibriumLiquidDensity
impl<N: Gradients> PropertyAD<N> for EquilibriumLiquidDensity
const REFERENCE: Density
type Unit = <SIUnit<0, 0, 0, 0, 0, 1, 0> as Sub<<<SIUnit<0, 1, 0, 0, 0, 0, 0> as Add>::Output as Add<SIUnit<0, 1, 0, 0, 0, 0, 0>>>::Output>>::Output
Sourcefn evaluate<E: Residual<N, D>, D: DualNum<f64, Inner = f64> + Copy>(
&self,
eos: &E,
) -> FeosResult<Density<D>>
fn evaluate<E: Residual<N, D>, D: DualNum<f64, Inner = f64> + Copy>( &self, eos: &E, ) -> FeosResult<Density<D>>
Evaluate the property for an arbitrary derivative.
Sourcefn evaluate_gradient<E: Residual<N, DualSVec<f64, f64, P>>, const P: usize>(
&self,
eos: &E,
) -> FeosResult<Quantity<DualSVec<f64, f64, P>, Self::Unit>>
fn evaluate_gradient<E: Residual<N, DualSVec<f64, f64, P>>, const P: usize>( &self, eos: &E, ) -> FeosResult<Quantity<DualSVec<f64, f64, P>, Self::Unit>>
Evaluate the property for the first derivative w.r.t. model parameters. Read more
Sourcefn evaluate_parallel<E: Residual<N> + Sync>(
eos: &E,
input: ArrayView2<'_, f64>,
) -> (Array1<f64>, Array1<bool>)
fn evaluate_parallel<E: Residual<N> + Sync>( eos: &E, input: ArrayView2<'_, f64>, ) -> (Array1<f64>, Array1<bool>)
Evaluate the property for all inputs in parallel. Read more
Sourcefn evaluate_parallel_derivatives<E: ParametersAD<N>, const P: usize>(
parameter_names: [String; P],
parameters: &[f64],
input: ArrayView2<'_, f64>,
) -> (Array1<f64>, Array2<f64>, Array1<bool>)
fn evaluate_parallel_derivatives<E: ParametersAD<N>, const P: usize>( parameter_names: [String; P], parameters: &[f64], input: ArrayView2<'_, f64>, ) -> (Array1<f64>, Array2<f64>, Array1<bool>)
Evaluate the property and its gradients for all inputs in parallel. Read more
Sourcefn evaluate_parallel_derivatives_params<E: ParametersAD<N>, const P: usize>(
parameter_names: [String; P],
parameters: ArrayView2<'_, f64>,
input: ArrayView2<'_, f64>,
) -> (Array1<f64>, Array2<f64>, Array1<bool>)
fn evaluate_parallel_derivatives_params<E: ParametersAD<N>, const P: usize>( parameter_names: [String; P], parameters: ArrayView2<'_, f64>, input: ArrayView2<'_, f64>, ) -> (Array1<f64>, Array2<f64>, Array1<bool>)
Evaluate the property and its gradients for all inputs and parameters in parallel. Read more