Module parameter

Module parameter 

Structures and traits that can be used to build model parameters for equations of state.

Structs

AssociationParameters
Parameter set required for the SAFT association Helmoltz energy contribution and functional.
AssociationRecord
Pure component association parameters.
AssociationSite
The definition of an individual association site.
BinaryAssociationRecord
Binary association parameters.
BinaryParameters
Parameters for one specific binary interaction.
BinaryRecord
A collection of parameters that model interactions between two substances.
ChemicalRecord
Chemical information of a substance.
GenericParameters
The most general representation of model parameters.
Identifier
A collection of identifiers for a chemical structure or substance.
PureParameters
Parameters for one specific pure component or segment/group.
Record
A collection of parameters with an arbitrary identifier.

Enums

IdentifierOption
Possible variants to identify a substance.

Traits

CombiningRule
The combining rule for association parameters that is used as fallback if no binary association parameters are available.
FromSegments
Trait for models that implement a homosegmented group contribution method
FromSegmentsBinary
Trait for models that implement a homosegmented group contribution method and have a combining rule for binary interaction parameters.
GroupCount
The type that is used to account for the multiplicity of groups.

Type Aliases

BinarySegmentRecord
A collection of parameters that model interactions between two segments.
GcParameters
Representation of group-specific parameters.
IdealGasParameters
Representation of parameters for ideal gas models (no association, no binary interactions).
Parameters
Representation of component-specific parameters (no bonds, no counts).
PureRecord
A collection of parameters of a pure substance.
SegmentRecord
Parameters describing an individual segment of a molecule.