FromSegments

Trait FromSegments 

pub trait FromSegments: Clone {
    // Required method
    fn from_segments(segments: &[(Self, f64)]) -> FeosResult<Self>;
}
Trait for models that implement a homosegmented group contribution method

Required Methods

fn from_segments(segments: &[(Self, f64)]) -> FeosResult<Self>

Constructs the record from a list of segment records with their number of occurences.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors