pub struct EquationOfState<I, R> {
pub ideal_gas: I,
pub residual: R,
}Expand description
An equation of state consisting of an ideal gas model and a residual Helmholtz energy model.
Fields
ideal_gas: Iresidual: RImplementations
Sourceimpl<I, R> EquationOfState<I, R>
impl<I, R> EquationOfState<I, R>
Sourcepub fn new(ideal_gas: I, residual: R) -> Self
pub fn new(ideal_gas: I, residual: R) -> Self
Return a new EquationOfState with the given ideal gas and residual models.
Sourceimpl<I> EquationOfState<Vec<I>, NoResidual>
impl<I> EquationOfState<Vec<I>, NoResidual>
Sourcepub fn ideal_gas(ideal_gas: Vec<I>) -> Self
pub fn ideal_gas(ideal_gas: Vec<I>) -> Self
Return a new EquationOfState that only consists of an ideal gas models.