Struct feos_core::PhaseDiagram

source ·
pub struct PhaseDiagram<E, const N: usize> {
    pub states: Vec<PhaseEquilibrium<E, N>>,
}
Pure component and binary mixture phase diagrams.

Fields

states: Vec<PhaseEquilibrium<E, N>>

Implementations

source

impl<E: Residual> PhaseDiagram<E, 2>

source

pub fn binary_vle<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, npoints: Option<usize>, x_lle: Option<(f64, f64)>, bubble_dew_options: (SolverOptions, SolverOptions) ) -> EosResult<Self>

Create a new binary phase diagram exhibiting a vapor/liquid equilibrium.

If a heteroazeotrope occurs and the composition of the liquid phases are known, they can be passed as x_lle to avoid the calculation of unstable branches.

source

pub fn lle<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, feed: &Moles<Array1<f64>>, min_tp: TP::Other, max_tp: TP::Other, npoints: Option<usize> ) -> EosResult<Self>

Create a new phase diagram using Tp flash calculations.

The usual use case for this function is the calculation of liquid-liquid phase diagrams, but it can be used for vapor- liquid diagrams as well, as long as the feed composition is in a two phase region.

source

impl<E: Residual> PhaseDiagram<E, 2>

source

pub fn binary_vlle<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, x_lle: (f64, f64), tp_lim_lle: Option<TP::Other>, tp_init_vlle: Option<TP::Other>, npoints_vle: Option<usize>, npoints_lle: Option<usize>, bubble_dew_options: (SolverOptions, SolverOptions) ) -> EosResult<PhaseDiagramHetero<E>>

Create a new binary phase diagram exhibiting a vapor/liquid/liquid equilibrium.

The x_lle parameter is used as initial values for the calculation of the heteroazeotrope.

source

impl<E, const N: usize> PhaseDiagram<E, N>

source

pub fn new(states: Vec<PhaseEquilibrium<E, N>>) -> Self

Create a phase diagram from a list of phase equilibria.

source

impl<E: Residual> PhaseDiagram<E, 2>

source

pub fn pure( eos: &Arc<E>, min_temperature: Temperature, npoints: usize, critical_temperature: Option<Temperature>, options: SolverOptions ) -> EosResult<Self>

Calculate a phase diagram for a pure component.

source

pub fn vapor(&self) -> StateVec<'_, E>

Return the vapor states of the diagram.

source

pub fn liquid(&self) -> StateVec<'_, E>

Return the liquid states of the diagram.

source

impl<E: Residual> PhaseDiagram<E, 2>

source

pub fn par_pure( eos: &Arc<E>, min_temperature: Temperature, npoints: usize, chunksize: usize, thread_pool: ThreadPool, critical_temperature: Option<Temperature>, options: SolverOptions ) -> EosResult<Self>

source

impl<E: Residual> PhaseDiagram<E, 2>

source

pub fn bubble_point_line( eos: &Arc<E>, moles: &Moles<Array1<f64>>, min_temperature: Temperature, npoints: usize, critical_temperature: Option<Temperature>, options: (SolverOptions, SolverOptions) ) -> EosResult<Self>

Calculate the bubble point line of a mixture with given composition.

source

pub fn dew_point_line( eos: &Arc<E>, moles: &Moles<Array1<f64>>, min_temperature: Temperature, npoints: usize, critical_temperature: Option<Temperature>, options: (SolverOptions, SolverOptions) ) -> EosResult<Self>

Calculate the dew point line of a mixture with given composition.

source

pub fn spinodal( eos: &Arc<E>, moles: &Moles<Array1<f64>>, min_temperature: Temperature, npoints: usize, critical_temperature: Option<Temperature>, options: SolverOptions ) -> EosResult<Self>

Calculate the spinodal lines for a mixture with fixed composition.