PhaseEquilibrium

Struct PhaseEquilibrium 

pub struct PhaseEquilibrium<E, const P: usize, N: Dim = Dyn, D: DualNum<f64> + Copy = f64>{
    pub states: [State<E, N, D>; P],
    pub phase_fractions: [D; P],
    /* private fields */
}
A thermodynamic equilibrium state.

The struct is parametrized over the number of phases with most features being implemented for the two phase vapor/liquid or liquid/liquid case.

Contents

Fields

states: [State<E, N, D>; P]phase_fractions: [D; P]

Implementations

Source

impl<E: Residual<N, D>, N: Gradients, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, N, D>

Pure component phase equilibria

pub fn pure<TP: TemperatureOrPressure<D>>( eos: &E, temperature_or_pressure: TP, initial_state: Option<&Self>, options: SolverOptions, ) -> FeosResult<Self>

Calculate a phase equilibrium for a pure component.

pub fn pure_t( eos: &E, temperature: Temperature<D>, initial_state: Option<&Self>, options: SolverOptions, ) -> FeosResult<(Pressure<D>, [Density<D>; 2])>

Calculate a phase equilibrium for a pure component and given temperature.

Source

impl<E: Residual<N, D>, N: Gradients, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, N, D>

pub fn pure_p( eos: &E, pressure: Pressure<D>, initial_state: Option<&Self>, options: SolverOptions, ) -> FeosResult<(Temperature<D>, [Density<D>; 2])>

Calculate a phase equilibrium for a pure component and given pressure.

Source

impl<E: Residual + Subset> PhaseEquilibrium<E, 2>

pub fn vapor_pressure( eos: &E, temperature: Temperature, ) -> Vec<Option<Pressure>>

Calculate the pure component vapor pressures of all components in the system for the given temperature.

pub fn boiling_temperature( eos: &E, pressure: Pressure, ) -> Vec<Option<Temperature>>

Calculate the pure component boiling temperatures of all components in the system for the given pressure.

pub fn vle_pure_comps<TP: TemperatureOrPressure>( eos: &E, temperature_or_pressure: TP, ) -> Vec<Option<PhaseEquilibrium<E, 2>>>

Calculate the pure component phase equilibria of all components in the system.

Source

impl<E: Residual<N, D>, N: Gradients, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, N, D>

Bubble and dew point calculations

pub fn bubble_point<TP: TemperatureOrPressure<D>, X: Composition<D, N>>( eos: &E, temperature_or_pressure: TP, liquid_molefracs: X, tp_init: Option<TP::Other>, vapor_molefracs: Option<&OVector<f64, N>>, options: (SolverOptions, SolverOptions), ) -> FeosResult<Self>

Calculate a phase equilibrium for a given temperature or pressure and composition of the liquid phase.

pub fn dew_point<TP: TemperatureOrPressure<D>, X: Composition<D, N>>( eos: &E, temperature_or_pressure: TP, vapor_molefracs: X, tp_init: Option<TP::Other>, liquid_molefracs: Option<&OVector<f64, N>>, options: (SolverOptions, SolverOptions), ) -> FeosResult<Self>

Calculate a phase equilibrium for a given temperature or pressure and composition of the vapor phase.

Source

impl<E: Residual<N>, N: Gradients> PhaseEquilibrium<E, 2, N>

Flash calculations

pub fn tp_flash<X: Composition<f64, N>>( eos: &E, temperature: Temperature, pressure: Pressure, feed: X, initial_state: Option<&PhaseEquilibrium<E, 2, N>>, options: SolverOptions, non_volatile_components: Option<Vec<usize>>, ) -> FeosResult<Self>

Perform a Tp-flash calculation. If no initial values are given, the solution is initialized using a stability analysis.

The algorithm can be use to calculate phase equilibria of systems containing non-volatile components (e.g. ions).

Source

impl<E: Residual<U2, D>, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, U2, D>

pub fn tp_flash_binary<X: Composition<D, U2>>( eos: &E, temperature: Temperature<D>, pressure: Pressure<D>, feed: X, options: SolverOptions, ) -> FeosResult<Self>

Perform a Tp-flash calculation for a binary mixture. Compared to the version of the algorithm for a generic number of components (tp_flash), this can be used in combination with automatic differentiation.

Source

impl<E: Total<N, D>, N: Gradients + DimAdd<U2> + DimAdd<U3>, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, N, D>
where DefaultAllocator: Allocator<N> + Allocator<N, N> + Allocator<<N as DimAdd<U3>>::Output> + Allocator<U1, <N as DimAdd<U3>>::Output> + Allocator<<N as DimAdd<U3>>::Output, <N as DimAdd<U3>>::Output> + Allocator<<N as DimAdd<U2>>::Output> + Allocator<U1, <N as DimAdd<U2>>::Output> + Allocator<<N as DimAdd<U2>>::Output, <N as DimAdd<U2>>::Output>, <N as DimAdd<U3>>::Output: Gradients, <N as DimAdd<U2>>::Output: Gradients,

pub fn ph_flash<X: Composition<D, N>>( eos: &E, pressure: Pressure<D>, molar_enthalpy: MolarEnergy<D>, feed: X, initial_temperature: Temperature, options: SolverOptions, ) -> FeosResult<Self>

Perform a ph-flash calculation. An initial temperature is required and the system needs to be in the two-phase region at that initial temperature.

based on Michelsen’s work State function based flash specifications

pub fn ps_flash<X: Composition<D, N>>( eos: &E, pressure: Pressure<D>, molar_entropy: MolarEntropy<D>, feed: X, initial_temperature: Temperature, options: SolverOptions, ) -> FeosResult<Self>

Perform a ps-flash calculation. An initial temperature is required and the system needs to be in the two-phase region at that initial temperature.

based on Michelsen’s work State function based flash specifications

Source

impl<E: Residual> PhaseEquilibrium<E, 3>

Heteroazeotropes

pub fn heteroazeotrope<TP: TemperatureOrPressure>( eos: &E, temperature_or_pressure: TP, x_init: (f64, f64), tp_init: Option<TP::Other>, options: SolverOptions, bubble_dew_options: (SolverOptions, SolverOptions), ) -> FeosResult<Self>

Calculate a heteroazeotrope (three phase equilbrium) for a binary system and given temperature or pressure.

Source

impl<E: Residual + Subset> PhaseEquilibrium<E, 2>

Azeotrope detection

pub fn binary_azeotrope<TP: TemperatureOrPressure>( eos: &E, temperature_or_pressure: TP, ) -> FeosResult<Option<Self>>

Calculate the azeotropic state in a binary system. If no azeotrope is expected, the function returns None.

Source

impl<E: Residual, const P: usize> PhaseEquilibrium<E, P>

pub fn _repr_markdown_(&self) -> String

Source

impl<E: Residual<N, D>, N: Dim, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, N, D>

pub fn vapor(&self) -> &State<E, N, D>

pub fn liquid(&self) -> &State<E, N, D>

pub fn vapor_phase_fraction(&self) -> D

Source

impl<E> PhaseEquilibrium<E, 3>

pub fn vapor(&self) -> &State<E>

pub fn liquid1(&self) -> &State<E>

pub fn liquid2(&self) -> &State<E>

Source

impl<E: Residual<N, D>, N: Dim, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 2, N, D>

pub fn single_phase(state: State<E, N, D>) -> Self

pub fn two_phase(vapor: State<E, N, D>, liquid: State<E, N, D>) -> Self

pub fn with_vapor_phase_fraction( vapor: State<E, N, D>, liquid: State<E, N, D>, vapor_phase_fraction: D, total_moles: Option<Moles<D>>, ) -> Self

Source

impl<E: Residual<N, D>, N: Dim, D: DualNum<f64> + Copy> PhaseEquilibrium<E, 3, N, D>

pub fn new( vapor: State<E, N, D>, liquid1: State<E, N, D>, liquid2: State<E, N, D>, ) -> Self

Source

impl<E: Residual<N, D>, N: Gradients, const P: usize, D: DualNum<f64> + Copy> PhaseEquilibrium<E, P, N, D>

pub fn total_moles(&self) -> FeosResult<Moles<D>>

Source

impl<E: Total<N, D>, N: Gradients, const P: usize, D: DualNum<f64> + Copy> PhaseEquilibrium<E, P, N, D>

pub fn molar_enthalpy(&self) -> MolarEnergy<D>

pub fn enthalpy(&self) -> FeosResult<Energy<D>>

pub fn molar_entropy(&self) -> MolarEntropy<D>

pub fn entropy(&self) -> FeosResult<Entropy<D>>

Source

impl<E: Residual<N>, N: Dim> PhaseEquilibrium<E, 2, N>

Utility functions

pub fn is_trivial_solution(state1: &State<E, N>, state2: &State<E, N>) -> bool

Check if the two states form a trivial solution