ParametersAD

Trait ParametersAD 

pub trait ParametersAD<const N: usize>: for<'a> From<&'a [f64]> + Residual<Const<N>> {
    // Required method
    fn index_parameters_mut<'a, const P: usize>(
        eos: &'a mut Self::Lifted<DualSVec<f64, f64, P>>,
        index: &str,
    ) -> &'a mut DualSVec<f64, f64, P>;

    // Provided method
    fn named_derivatives<const P: usize>(
        &self,
        parameter_names: [&str; P],
    ) -> Self::Lifted<DualSVec<f64, f64, P>> { ... }
}
A model that can be evaluated with derivatives of its parameters.

Required Methods

fn index_parameters_mut<'a, const P: usize>( eos: &'a mut Self::Lifted<DualSVec<f64, f64, P>>, index: &str, ) -> &'a mut DualSVec<f64, f64, P>

Return a mutable reference to the parameter named by index from the parameter set.

Provided Methods

fn named_derivatives<const P: usize>( &self, parameter_names: [&str; P], ) -> Self::Lifted<DualSVec<f64, f64, P>>

Return the parameters with the appropriate derivatives.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors