Subset

Trait Subset 

pub trait Subset {
    // Required method
    fn subset(&self, component_list: &[usize]) -> Self;
}
A model from which models for subsets of its components can be extracted.

Required Methods

fn subset(&self, component_list: &[usize]) -> Self

Return a model consisting of the components contained in component_list.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: Subset> Subset for Arc<T>

Source

fn subset(&self, component_list: &[usize]) -> Self

Implementors