Structures and traits that can be used to build model parameters for equations of state.
Structs
- Association
Parameters - Parameter set required for the SAFT association Helmoltz energy contribution and functional.
- Association
Record - Pure component association parameters.
- Association
Site - The definition of an individual association site.
- Binary
Association Record - Binary association parameters.
- Binary
Parameters - Parameters for one specific binary interaction.
- Binary
Record - A collection of parameters that model interactions between two substances.
- Chemical
Record - Chemical information of a substance.
- Generic
Parameters - The most general representation of model parameters.
- Identifier
- A collection of identifiers for a chemical structure or substance.
- Pure
Parameters - Parameters for one specific pure component or segment/group.
- Record
- A collection of parameters with an arbitrary identifier.
Enums
- Identifier
Option - Possible variants to identify a substance.
Traits
- Combining
Rule - The combining rule for association parameters that is used as fallback if no binary association parameters are available.
- From
Segments - Trait for models that implement a homosegmented group contribution method
- From
Segments Binary - Trait for models that implement a homosegmented group contribution method and have a combining rule for binary interaction parameters.
- Group
Count - The type that is used to account for the multiplicity of groups.
Type Aliases
- Binary
Segment Record - A collection of parameters that model interactions between two segments.
- GcParameters
- Representation of group-specific parameters.
- Ideal
GasParameters - Representation of parameters for ideal gas models (no association, no binary interactions).
- Parameters
- Representation of component-specific parameters (no bonds, no counts).
- Pure
Record - A collection of parameters of a pure substance.
- Segment
Record - Parameters describing an individual segment of a molecule.