pub struct PhaseEquilibrium<E, const N: usize>(/* private fields */);
A thermodynamic equilibrium state.

The struct is parametrized over the number of phases with most features being implemented for the two phase vapor/liquid or liquid/liquid case.

Contents

Implementations

source

impl<E: Residual> PhaseEquilibrium<E, 2>

source

pub fn bubble_point<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, liquid_molefracs: &Array1<f64>, tp_init: Option<TP::Other>, vapor_molefracs: Option<&Array1<f64>>, options: (SolverOptions, SolverOptions) ) -> EosResult<Self>

Calculate a phase equilibrium for a given temperature or pressure and composition of the liquid phase.

source

pub fn dew_point<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, vapor_molefracs: &Array1<f64>, tp_init: Option<TP::Other>, liquid_molefracs: Option<&Array1<f64>>, options: (SolverOptions, SolverOptions) ) -> EosResult<Self>

Calculate a phase equilibrium for a given temperature or pressure and composition of the vapor phase.

source

impl<E: Residual> PhaseEquilibrium<E, 3>

source

pub fn heteroazeotrope<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, x_init: (f64, f64), tp_init: Option<TP::Other>, options: SolverOptions, bubble_dew_options: (SolverOptions, SolverOptions) ) -> EosResult<Self>

Calculate a heteroazeotrope (three phase equilbrium) for a binary system and given temperature or pressure.

source

impl<E: Residual> PhaseEquilibrium<E, 2>

source

pub fn tp_flash( eos: &Arc<E>, temperature: Temperature, pressure: Pressure, feed: &Moles<Array1<f64>>, initial_state: Option<&PhaseEquilibrium<E, 2>>, options: SolverOptions, non_volatile_components: Option<Vec<usize>> ) -> EosResult<Self>

Perform a Tp-flash calculation. If no initial values are given, the solution is initialized using a stability analysis.

The algorithm can be use to calculate phase equilibria of systems containing non-volatile components (e.g. ions).

source

impl<E: Residual> PhaseEquilibrium<E, 2>

source

pub fn pure<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP, initial_state: Option<&PhaseEquilibrium<E, 2>>, options: SolverOptions ) -> EosResult<Self>

Calculate a phase equilibrium for a pure component.

source

impl<E: Residual> PhaseEquilibrium<E, 2>

source

pub fn vapor_pressure( eos: &Arc<E>, temperature: Temperature ) -> Vec<Option<Pressure>>

Calculate the pure component vapor pressures of all components in the system for the given temperature.

source

pub fn boiling_temperature( eos: &Arc<E>, pressure: Pressure ) -> Vec<Option<Temperature>>

Calculate the pure component boiling temperatures of all components in the system for the given pressure.

source

pub fn vle_pure_comps<TP: TemperatureOrPressure>( eos: &Arc<E>, temperature_or_pressure: TP ) -> Vec<Option<PhaseEquilibrium<E, 2>>>

Calculate the pure component phase equilibria of all components in the system.

source

impl<E: Residual, const N: usize> PhaseEquilibrium<E, N>

source

pub fn _repr_markdown_(&self) -> String

source

impl<E> PhaseEquilibrium<E, 2>

source

pub fn vapor(&self) -> &State<E>

source

pub fn liquid(&self) -> &State<E>

source

impl<E> PhaseEquilibrium<E, 3>

source

pub fn vapor(&self) -> &State<E>

source

pub fn liquid1(&self) -> &State<E>

source

pub fn liquid2(&self) -> &State<E>

source

impl<E: Residual> PhaseEquilibrium<E, 2>

source

pub fn new_npt( eos: &Arc<E>, temperature: Temperature, pressure: Pressure, vapor_moles: &Moles<Array1<f64>>, liquid_moles: &Moles<Array1<f64>> ) -> EosResult<Self>

Creates a new PhaseEquilibrium that contains two states at the specified temperature, pressure and moles.

The constructor can be used in custom phase equilibrium solvers or, e.g., to generate initial guesses for an actual VLE solver. In general, the two states generated are NOT in an equilibrium.

source

impl<E: Residual> PhaseEquilibrium<E, 2>

source

pub fn is_trivial_solution(state1: &State<E>, state2: &State<E>) -> bool

Check if the two states form a trivial solution